@@ -1,6 +1,7 @@
 """ Frame is the Client Framework that verifies and installs entries,
 and generates statistics. """
 
+import copy
 import time
 import fnmatch
 import logging
@@ -328,11 +329,13 @@ class Frame(object):
             if bundle.tag != 'Bundle':
                 continue
             bmodified = len([item for item in bundle
-                             if item in self.whitelist])
+                             if item in self.whitelist or
+                             item in self.modified])
             actions = [a for a in bundle.findall('./Action')
                        if (a.get('timing') != 'post' and
                            (bmodified or a.get('when') == 'always'))]
-            # now we process all "always actions"
+            # now we process all "pre" and "both" actions that are either
+            # always or the bundle has been modified
             if self.setup['interactive']:
                 self.promptFilter(iprompt, actions)
             self.DispatchInstallCalls(actions)
@@ -522,7 +525,7 @@ class Frame(object):
             container = Bcfg2.Client.XML.SubElement(stats, ename)
             for item in data:
                 item.set('qtext', '')
-                container.append(item)
+                container.append(copy.deepcopy(item))
                 item.text = None
 
         timeinfo = Bcfg2.Client.XML.Element("OpStamps")
