@@ -18,6 +18,7 @@ from django.core import management
 from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
 from django.db.models import FieldDoesNotExist
 from django.core.cache import cache
+from django import db
 
 #Used by GetCurrentEntry
 import difflib
@@ -166,7 +167,7 @@ class DjangoORM(StorageBase):
         # TODO - vcs output
         act_dict['detail_type'] = PathEntry.DETAIL_UNUSED
         if path_type == 'directory' and entry.get('prune', 'false') == 'true':
-            unpruned_elist = [e.get('path') for e in entry.findall('Prune')]
+            unpruned_elist = [e.get('name') for e in entry.findall('Prune')]
             if unpruned_elist:
                 act_dict['detail_type'] = PathEntry.DETAIL_PRUNED
                 act_dict['details'] = "\n".join(unpruned_elist)
@@ -370,6 +371,11 @@ class DjangoORM(StorageBase):
         except:
             self.logger.error("Failed to import interaction: %s" %
                     traceback.format_exc().splitlines()[-1])
+        finally:
+            self.logger.debug("%s: Closing database connection" %
+                              self.__class__.__name__)
+            db.close_connection()
+
 
     def validate(self):
         """Validate backend storage.  Should be called once when loaded"""
@@ -451,4 +457,3 @@ class DjangoORM(StorageBase):
             else:
                 ret.append(None)
         return ret
-
