@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from Bcfg2.Reporting.Compat.django_urls import *
 from django.conf import settings
 from django.views.generic.simple import direct_to_template
 from django.contrib import admin
