@@ -27,7 +27,14 @@ class TestPOSIXUsers(TestTool):
     def get_obj(self, logger=None, setup=None, config=None):
         if setup is None:
             setup = MagicMock()
-            setup.__getitem__.return_value = []
+            def getitem(key):
+                if key == 'encoding':
+                    return 'UTF-8'
+                else:
+                    return []
+
+            setup.__getitem__.side_effect = getitem
+
         return TestTool.get_obj(self, logger, setup, config)
 
     @patch("pwd.getpwall")
@@ -381,15 +388,15 @@ class TestPOSIXUsers(TestTool):
                  (lxml.etree.Element("POSIXUser", name="test", group="test",
                                      home="/home/test", shell="/bin/zsh",
                                      gecos="Test McTest"),
-                  ["-m", "-g", "test", "-d", "/home/test", "-s", "/bin/zsh",
+                  ["-g", "test", "-d", "/home/test", "-s", "/bin/zsh",
                    "-c", "Test McTest"]),
                  (lxml.etree.Element("POSIXUser", name="test", group="test",
                                      home="/home/test", shell="/bin/zsh",
                                      gecos="Test McTest", uid="1001"),
-                  ["-m", "-u", "1001", "-g", "test", "-d", "/home/test",
+                  ["-u", "1001", "-g", "test", "-d", "/home/test",
                    "-s", "/bin/zsh", "-c", "Test McTest"]),
                  (entry,
-                  ["-m", "-g", "test", "-G", "wheel,users", "-d", "/home/test",
+                  ["-g", "test", "-G", "wheel,users", "-d", "/home/test",
                    "-s", "/bin/zsh", "-c", "Test McTest"])]
         for entry, expected in cases:
             for action in ["add", "mod", "del"]:
