@@ -7,11 +7,11 @@ if __name__ == '__main__':
     dir = argv[1]
     imagename = dir.split('/')[-1]
     e = Element("Image", name=imagename)
-    for line in open("%s/base.ConfigFile"%(dir)).readlines():
+    for line in open("%s/base.ConfigFile" % (dir)).readlines():
         SubElement(e, "ConfigFile", name=line.strip())
-    for line in open("%s/base.Package"%(dir)).readlines():
+    for line in open("%s/base.Package" % (dir)).readlines():
         SubElement(e, "Package", name=line.strip())
-    for line in open("%s/base.Service"%(dir)).readlines():
+    for line in open("%s/base.Service" % (dir)).readlines():
         SubElement(e, "Service", name=line.strip().split()[0])
 
-    print tostring(e)
+    print(tostring(e))
