@@ -1,36 +1,50 @@
 #!/usr/bin/python
-import sys, os
-os.environ['DJANGO_SETTINGS_MODULE'] = 'Hostbase.settings'
-from Hostbase.hostbase.models import Host, Interface
+import os
 from getopt import getopt, GetoptError
 from re import split
+import sys
 
-attribs = ['hostname', 'whatami', 'netgroup', 'security_class', 'support',
-           'csi', 'printq', 'dhcp', 'outbound_smtp', 'primary_user',
-           'administrator', 'location', 'expiration_date', 'comments',
-           'status', 'last']
+os.environ['DJANGO_SETTINGS_MODULE'] = 'Hostbase.settings'
+from Hostbase.hostbase.models import Host
+
+attribs = ['administrator',
+           'comments',
+           'csi',
+           'dhcp',
+           'expiration_date',
+           'hostname',
+           'last',
+           'location',
+           'netgroup',
+           'outbound_smtp',
+           'primary_user',
+           'printq',
+           'security_class',
+           'support',
+           'status',
+           'whatami']
 
 already_exists = None
 #here's my attempt at making the command line idiot proof
 #you must supply and arugument and hostname for hostbase.py to run
 try:
-    (opts, args) = getopt(sys.argv[1:],'l:c:')
+    (opts, args) = getopt(sys.argv[1:], 'l:c:')
     sys.argv[1]
     if len(split("\.", opts[0][1])) == 1:
         hosttouse = opts[0][1] + ".mcs.anl.gov"
     else:
         hosttouse = opts[0][1]
 except (GetoptError, IndexError):
-    print "\nUsage: hostbase.py -flag (hostname)\n"
-    print "Flags:"
-    print "\t-l   look (hostname)\n"
-#    print "\t-c   copy (hostname)\n"
+    print("\nUsage: hostbase.py -flag (hostname)\n")
+    print("Flags:")
+    print("\t-l   look (hostname)\n")
+#    print("\t-c   copy (hostname)\n")
     sys.exit()
 
 try:
     host = Host.objects.get(hostname=hosttouse)
 except:
-    print "Error: host %s not in hostbase" % hosttouse
+    print("Error: host %s not in hostbase" % hosttouse)
     sys.exit(1)
 interfaces = []
 for interface in host.interface_set.all():
@@ -53,7 +67,7 @@ for interface in interfaces:
 
 if opts[0][0] == '-l':
     """Displays general host information"""
-    print hostinfo
+    print(hostinfo)
 
 if opts[0][0] == '-c':
     """Provides pre-filled template to copy a host record"""
