@@ -19,7 +19,6 @@ def myListPkgs(self, lst, description, outputType):
         thingslisted = 0
         if len(lst) > 0:
             thingslisted = 1
-            #print '%s' % description
             from yum.misc import sortPkgObj
             lst.sort(sortPkgObj)
             for pkg in lst:
@@ -40,5 +39,5 @@ try:
     sys.argv = [sys.argv[0], '-d', '0', 'list']
     yummain.main(sys.argv[1:])
 except KeyboardInterrupt:
-    print("\n\nExiting on user cancel.", file=sys.stderr)
+    sys.stderr.write("\n\nExiting on user cancel.")
     sys.exit(1)
